==> ell-0.6.tar.gz: ell-0.6/ell/ell.h <==
/*
 *
 *  Embedded Linux library
 *
 *  Copyright (C) 2011-2014  Intel Corporation. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include <ell/util.h>
#include <ell/test.h>
#include <ell/queue.h>
#include <ell/hashmap.h>
#include <ell/string.h>
#include <ell/main.h>
#include <ell/idle.h>
#include <ell/signal.h>
#include <ell/timeout.h>
#include <ell/io.h>
#include <ell/ringbuf.h>
#include <ell/log.h>
#include <ell/plugin.h>
#include <ell/checksum.h>
#include <ell/settings.h>
#include <ell/hwdb.h>
#include <ell/cipher.h>
#include <ell/random.h>
#include <ell/uintset.h>
#include <ell/base64.h>
#include <ell/pem.h>
#include <ell/tls.h>
#include <ell/uuid.h>
#include <ell/key.h>
#include <ell/pkcs5.h>
#include <ell/file.h>
#include <ell/net.h>
#include <ell/netlink.h>
#include <ell/genl.h>
#include <ell/dbus.h>
#include <ell/dbus-service.h>
#include <ell/dbus-client.h>
#include <ell/dhcp.h>

==> ell-0.17.tar.gz: ell-0.17/ell/ell.h <==
/*
 *
 *  Embedded Linux library
 *
 *  Copyright (C) 2011-2014  Intel Corporation. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include <ell/util.h>
#include <ell/test.h>
#include <ell/strv.h>
#include <ell/utf8.h>
#include <ell/queue.h>
#include <ell/hashmap.h>
#include <ell/string.h>
#include <ell/main.h>
#include <ell/idle.h>
#include <ell/signal.h>
#include <ell/timeout.h>
#include <ell/io.h>
#include <ell/ringbuf.h>
#include <ell/log.h>
#include <ell/plugin.h>
#include <ell/checksum.h>
#include <ell/settings.h>
#include <ell/hwdb.h>
#include <ell/cipher.h>
#include <ell/random.h>
#include <ell/uintset.h>
#include <ell/base64.h>
#include <ell/pem.h>
#include <ell/tls.h>
#include <ell/uuid.h>
#include <ell/key.h>
#include <ell/pkcs5.h>
#include <ell/file.h>
#include <ell/dir.h>
#include <ell/net.h>
#include <ell/netlink.h>
#include <ell/genl.h>
#include <ell/dbus.h>
#include <ell/dbus-service.h>
#include <ell/dbus-client.h>
#include <ell/dhcp.h>
#include <ell/cert.h>
#include <ell/ecc.h>
#include <ell/ecdh.h>
